/**
 Copyright 2018 Alibaba Group

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

'use strict';

import MultiTouchGesture from '../multitouch';
import CommonHandler from './common';

export default class PinchHandler extends CommonHandler {

  constructor(binding) {
    super(binding);
    let {anchor} = binding.options;
    let pinchGesture = this.pinchGesture = new MultiTouchGesture(anchor, binding.options.options);
    pinchGesture.on('pinch', this._onPinch);
    pinchGesture.on('pinchstart', this._onPinchStart);
    pinchGesture.on('pinchend', this._onPinchEnd);
  }

  _onPinch = (e) => {
    let scale = e.scale;
    let {props = []} = this.binding.options;
    props.forEach((prop) => {
      let {element, property, expression} = prop;
      let transformed = JSON.parse(expression.transformed);
      let val = this.binding.getValue({s:scale}, transformed);
      this.binding.setProperty(element, property, val);
      // stop transition
      element.style.transition = '';
      element.style.webkitTransition = '';
    });
  }

  _onPinchStart = (e) => {
    this.binding.callback({scale: parseInt(e.scale), state: 'start'});
  }

  _onPinchEnd = (e) => {
    this.binding.callback({scale: parseInt(e.scale), state: 'end'});
  }

  destroy() {
    let pinchGesture = this.pinchGesture;
    pinchGesture.off('pinchstart', this._onPinchStart);
    pinchGesture.off('pinchend', this._onPinchEnd);
    pinchGesture.off('pinch', this._onPinch);
    pinchGesture.destroy();
  }


};